==> bigdata-common-0.1.56-sources.jar: cn/com/duiba/bigdata/common/biz/enums/tables/bigdata_offline/TuiaExt02LogDetailMonthEnum.java <==
package cn.com.duiba.bigdata.common.biz.enums.tables.bigdata_offline;

public enum TuiaExt02LogDetailMonthEnum {

    ABTEST_PLAN_ID("abtest_plan_id", "实验计划id"),

    ABTEST_GROUP_ID("abtest_group_id", "实验分组id"),

    ABTEST("ab_test", "实验计划和分组 字符串数组，每个元素的格式：实验计划id-实验分组id"),

    DATE_PARTITION("date_partition", "按天分区，格式：yyyyMMdd"),

    LOG_UUID("log_uuid", "唯一键"),

    UNIX_TIME("unix_time", "unix时间戳"),

    INNER_GROUP("inner_group", "公司业务分类，大类"),

    INNER_TYPE("inner_type", "日志分类，小类"),

    OPEN_ACCOUNT_ID("open_account_id", "媒体开户账号id"),

    EXT_ADVERT_ID("ext_advert_id", "外部广告id"),

    EXT_ADVERT_GROUP_ID("ext_advert_group_id", "外部广告组id"),

    EXT_IDEA_ID("ext_idea_id", "外部创意id"),

    PUT_SCENE("put_scene", "投放场景：1-点券直接上报；2-转化概率多o；3-点券概率多o；4-转化直接上报"),

    EXT_SLOT_ID("ext_slot_id", "外部联盟广告位id"),

    EXT_APP_ID("ext_app_id", "外部联盟媒体id"),

    SLOT_ACTIVITY_TYPE("slot_activity_type", "广告位活动投放类型：1-插件工具、2-活动工具、3-直投页、4-展示广告，5-浮标 6-激励等"),

    APP_ID("app_id", "媒体ID"),

    SLOT_ID("slot_id", "广告位ID"),

    ADVERT_ID("advert_id", "广告ID"),

    ORIENTATION_ID("orientation_id", "广告配置ID"),

    CHARGE_TYPE("charge_type", "计费类型 CPC/CPA"),

    DEPTH_TARGET_EFFECT_TYPE("depth_target_effect_type", "深度优化类型：0-落地页转化；1-安装；2-启动；3-注册；4-激活；5-登录；6-付费；7-进件；8-完件；9-签收；10-留存"),

    TARGET_EFFECT_TYPE("target_effect_type", "目标转化类型"),

    TUIA_ID("tuia_id", "订单id"),

    CONSUMER_ID("consumer_id", "用户id"),







    ;

    //hologres 中表定义的字段名称
    private final String tableFieldName;

    //字段备注
    private final String desc;

    TuiaExt02LogDetailMonthEnum(String tableFieldName, String desc) {
        this.tableFieldName = tableFieldName;
        this.desc = desc;
    }

    public String getTableFieldName() {
        return tableFieldName;
    }

    public String getDesc() {
        return desc;
    }


}

==> bigdata-common-0.1.75-sources.jar: cn/com/duiba/bigdata/common/biz/enums/tables/bigdata_offline/TuiaExt02LogDetailMonthEnum.java <==
package cn.com.duiba.bigdata.common.biz.enums.tables.bigdata_offline;

public enum TuiaExt02LogDetailMonthEnum {

    ABTEST_PLAN_ID("abtest_plan_id", "实验计划id"),

    ABTEST_GROUP_ID("abtest_group_id", "实验分组id"),

    ABTEST("ab_test", "实验计划和分组 字符串数组，每个元素的格式：实验计划id-实验分组id"),

    DATE_PARTITION("date_partition", "按天分区，格式：yyyyMMdd"),

    LOG_UUID("log_uuid", "唯一键"),

    UNIX_TIME("unix_time", "unix时间戳"),

    INNER_GROUP("inner_group", "公司业务分类，大类"),

    INNER_TYPE("inner_type", "日志分类，小类"),

    OPEN_ACCOUNT_ID("open_account_id", "媒体开户账号id"),

    EXT_ADVERT_ID("ext_advert_id", "外部广告id"),

    EXT_ADVERT_GROUP_ID("ext_advert_group_id", "外部广告组id"),

    EXT_IDEA_ID("ext_idea_id", "外部创意id"),

    PUT_SCENE("put_scene", "投放场景：1-点券直接上报；2-转化概率多o；3-点券概率多o；4-转化直接上报"),

    EXT_SLOT_ID("ext_slot_id", "外部联盟广告位id"),

    EXT_APP_ID("ext_app_id", "外部联盟媒体id"),

    SLOT_ACTIVITY_TYPE("slot_activity_type", "广告位活动投放类型：1-插件工具、2-活动工具、3-直投页、4-展示广告，5-浮标 6-激励等"),

    APP_ID("app_id", "媒体ID"),

    SLOT_ID("slot_id", "广告位ID"),

    ADVERT_ID("advert_id", "广告ID"),

    ORIENTATION_ID("orientation_id", "广告配置ID"),

    CHARGE_TYPE("charge_type", "计费类型 CPC/CPA"),

    DEPTH_TARGET_EFFECT_TYPE("depth_target_effect_type", "深度优化类型：0-落地页转化；1-安装；2-启动；3-注册；4-激活；5-登录；6-付费；7-进件；8-完件；9-签收；10-留存"),

    TARGET_EFFECT_TYPE("target_effect_type", "目标转化类型"),

    TUIA_ID("tuia_id", "订单id"),

    CONSUMER_ID("consumer_id", "用户id"),

    PROVINCE_NAME("province_name", "省份名称"),

    CITY_NAME("city_name", "城市名称"),

    HUODAO_DCVR_LEVEL("huodao_dcvr_level", "货到模型分层"),

    ISP_DCVR_LEVEL("isp_dcvr_level", "运营商模型分层"),

    HUIJIKA_DCVR_LEVEL("huijika_dcvr_level", "会籍卡模型分层"),

    VIDEO_DCVR_LEVEL("video_dcvr_level", "视频模型分层"),

    APP_DIST_DCVR_LEVEL("app_dist_dcvr_level", "应用分发模型分层"),

    PHONE_PROVINCE_NAME("phone_province_name", "手机号归属省份名称"),

    PHONE_CITY_NAME("phone_city_name", "手机号归属城市名称"),






    ;

    //hologres 中表定义的字段名称
    private final String tableFieldName;

    //字段备注
    private final String desc;

    TuiaExt02LogDetailMonthEnum(String tableFieldName, String desc) {
        this.tableFieldName = tableFieldName;
        this.desc = desc;
    }

    public String getTableFieldName() {
        return tableFieldName;
    }

    public String getDesc() {
        return desc;
    }


}
